@@ -12,14 +12,10 @@ from aniemore.utils.classes import (
     BaseRecognizer,
     RecognizerOutputMany,
     RecognizerOutputOne,
-    RecognizerOutputTuple
 )
 
 
 class TextRecognizer(BaseRecognizer):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     def _get_torch_scores(
             self,
             text: Union[str, List[str]],
@@ -58,10 +54,9 @@ class TextRecognizer(BaseRecognizer):
 
         Args:
           text(str): текст для анализа
-          text: str: 
 
         Returns:
-            результат распознования
+          результат распознования
         """
 
         scores = self._get_torch_scores(text, self.tokenizer, self.device)
@@ -77,7 +72,7 @@ class TextRecognizer(BaseRecognizer):
           texts: список текстов для анализа
 
         Returns:
-            результат распознования
+          результат распознования
         """
         scores = self._get_torch_scores(texts, self.tokenizer, self.device).detach().cpu().numpy()
         results: RecognizerOutputMany = self._get_many_results(texts, scores)
@@ -109,22 +104,15 @@ class TextEnhancer:
     _apply_te = None
 
     def __init__(self, setup_on_init: bool = True) -> None:
-        """
-        Инициализация класса
-        :param setup_on_init: Если True, модель будет загружена при инициализации класса
+        """Инициализация класса
+        Args:
+          setup_on_init: Если True, модель будет загружена при инициализации класса
         """
         if setup_on_init:
             self._load_model()
 
     def _load_model(self) -> None:
-        """Загрузка модели. Если она уже загружена, то ничего не произойдет
-        :return: None
-
-        Args:
-
-        Returns:
-
-        """
+        """Загрузка модели. Если она уже загружена, то ничего не произойдет."""
         if sys.platform == 'darwin':  # MacOS check
             warning_text = ("Silero models are not supported on MacOS. "
                             "To make it work, we've changed torch engine to `qnnpack`. Use this with caution.")
@@ -139,10 +127,8 @@ class TextEnhancer:
 
         Args:
           text: Текст, который нужно улучшить
-          text: str: 
 
         Returns:
           Улучшенный текст
-
         """
         return self._apply_te(text.lower(), lan='ru')
